pub struct Document { /* private fields */ }Implementations
Sourceimpl Document
impl Document
pub fn new() -> Self
pub fn version(&self) -> &str
pub fn objects(&self) -> &BTreeMap<ObjectId, PdfObject>
Sourcepub fn add_object(&mut self, id: ObjectId, obj: PdfObject)
pub fn add_object(&mut self, id: ObjectId, obj: PdfObject)
Inserts an object, keeping the first definition if an id is seen twice
(matches the previous Vec semantics where the first entry won).
pub fn get_object(&self, id: ObjectId) -> Option<&PdfObject>
pub fn get_object_mut(&mut self, id: ObjectId) -> Option<&mut PdfObject>
pub fn set_catalog(&mut self, id: ObjectId)
pub fn catalog(&self) -> Option<ObjectId>
pub fn set_info(&mut self, id: ObjectId)
pub fn info(&self) -> Option<ObjectId>